@@ -7,6 +7,7 @@ import sys
 from datetime import datetime
 from typing import Union
 
+import plogger
 from OpenSSL import crypto
 from OpenSSL.crypto import X509
 from cryptography import x509
@@ -19,19 +20,22 @@ from dateutil.parser import parse
 class CertClient:
     """Tool to work with server certs"""
 
-    def __init__(self, host: str, port: int = 443, initialize: bool = True):
+    def __init__(self, host: str, port: int = 443, initialize: bool = True, logger_enabled: bool = True):
         """
         :param host:
         :param port:
+        :param logger_enabled:
         """
 
         self.host = host
         self.port = port
+        self.logger = plogger.logger(self.__class__.__name__, enabled=logger_enabled)
+
         if initialize:
             try:
                 self.cert = self.load_certificate()
             except socket.gaierror as err:
-                print(f'Invalid host name ({self.host}). Do not use HTTP(S), WWW or "/" in the end.', file=sys.stderr)
+                self.logger.exception(f'Invalid host name ({self.host}). Do not use HTTP(S), WWW or "/" in the end.')
                 raise ValueError(err)
 
     # Core methods
@@ -47,9 +51,13 @@ class CertClient:
         """
 
         try:
+            self.logger.info(f'[{self.host}:{self.port}] Load a certificate (X509) from the string or bytes encoded.')
+            # noinspection PyTypeChecker
             return crypto.load_certificate(crypto.FILETYPE_PEM, buffer=self.get_certificate())
         except crypto.Error as err:
-            raise LookupError(f'Cannot load certificate: {err}')
+            msg_error = f'Cannot load certificate: {err}'
+            self.logger.exception(msg_error)
+            raise LookupError(msg_error)
 
     def _get_all_cert_methods(self) -> list:
         """Service method to get all available parent cert lib methods"""
@@ -187,6 +195,8 @@ class CertClient:
         :return:
         """
 
+        self.logger.info("-> Get all certificate's consolidated info")
+
         try:
             data = {
                 'version': self.get_version(),
@@ -202,10 +212,11 @@ class CertClient:
                 'fingerprint': self.get_fingerprint(brief=fp_brief),
             }
         except AttributeError as err:
-            msg = f'Something went wrong. ' \
-                  f'Perhaps, connection to the server ({self.host}) was not established. ' \
-                  f'Try "initialize=True" parameter. Error: {err}'
-            print(msg, file=sys.stderr)
+            msg_error = (f'Something went wrong. '
+                         f'Perhaps, connection to the server ({self.host}) was not established. '
+                         f'Try "initialize=True" parameter. Error: {err}')
+            self.logger.exception(msg_error)
             return {}
 
+        self.logger.info(f'<- {data}')
         return data
